pub fn build_context_window_info(
previous_window_id: usize,
current_window_id: usize,
) -> ChatMessageExpand description
The window-info system message injected at the start of each window.
pub fn build_context_window_info(
previous_window_id: usize,
current_window_id: usize,
) -> ChatMessageThe window-info system message injected at the start of each window.