pub fn try_load_metrics(session_dir: &Path) -> Option<SessionMetrics>Expand description
Try to load session metrics, returning None if the file doesn’t exist.
pub fn try_load_metrics(session_dir: &Path) -> Option<SessionMetrics>Try to load session metrics, returning None if the file doesn’t exist.