pub fn acquire_session_lock(session_dir: &Path) -> AgentResult<File>Expand description
Acquire an exclusive file lock on the session directory.
Prevents concurrent access from other processes. Returns an error if the session is already in use.
pub fn acquire_session_lock(session_dir: &Path) -> AgentResult<File>Acquire an exclusive file lock on the session directory.
Prevents concurrent access from other processes. Returns an error if the session is already in use.